import { Container } from "@quarter/container";
import { Entity } from "@quarter/support";
export class Application extends Container {
    constructor(config) {
        super();
        this.booted = false;
        this.providers = new Map();
        this.provide("app", this);
        this.provide("config", new Entity(config));
    }
    get config() {
        return this.make("config");
    }
    boot() {
        if (!this.booted) {
            this.providers.forEach((provider) => provider.boot());
            this.booted = true;
        }
    }
    register(Provider) {
        if (this.providers.has(Provider)) {
            return this.providers.get(Provider);
        }
        const provider = new Provider(this);
        this.providers.set(Provider, provider);
        provider.register();
        if (this.booted) {
            provider.boot();
        }
        return provider;
    }
}
//# sourceMappingURL=Application.js.map